@@ -1,6 +1,8 @@
 #include "library.h"
+#include <QSettings>
+#include <QFileInfo>
+
 #include <MauiKit3/FileBrowsing/fmstatic.h>
-#include <MauiKit3/Core/utils.h>
 
 Library *Library::m_instance = nullptr;
 
@@ -8,7 +10,10 @@ Library::Library(QObject *parent) : QObject(parent)
 {   
     static const auto defaultSources = QStringList({FMStatic::DesktopPath, FMStatic::DownloadsPath, FMStatic::DocumentsPath});
 
-    m_sources = UTIL::loadSettings("Sources", "Settings", defaultSources).toStringList();
+    QSettings settings;
+    settings.beginGroup("Settings");
+    m_sources = settings.value("Sources", defaultSources).toStringList();
+    settings.endGroup();
 }
 
 Library *Library::instance()
@@ -59,15 +64,19 @@ void Library::openFiles(QStringList files)
         }
     }
 
-    emit this->requestedFiles(res);
+    Q_EMIT this->requestedFiles(res);
 }
 
 void Library::removeSource(const QString &url)
 {
     m_sources.removeOne(url);
 
-    UTIL::saveSettings("Sources", m_sources, "Settings");
-    emit this->sourcesChanged(m_sources);
+    QSettings settings;
+    settings.beginGroup("Settings");
+    settings.setValue("Sources", m_sources);
+    settings.endGroup();
+
+    Q_EMIT this->sourcesChanged(m_sources);
 }
 
 void Library::addSources(const QStringList &urls)
@@ -75,8 +84,34 @@ void Library::addSources(const QStringList &urls)
     m_sources << urls;
     m_sources.removeDuplicates();
 
-    UTIL::saveSettings("Sources", m_sources, "Settings");
-    emit this->sourcesChanged(m_sources);
+    QSettings settings;
+    settings.beginGroup("Settings");
+    settings.setValue("Sources", m_sources);
+    settings.endGroup();
+
+    Q_EMIT this->sourcesChanged(m_sources);
+}
+
+bool Library::isPDF(const QString &url)
+{
+  return FMStatic::getMime(url) == "application/pdf";
+}
+
+bool Library::isPlainText(const QString &url)
+{
+    return FMStatic::checkFileType(FMStatic::FILTER_TYPE::TEXT, FMStatic::getMime(url));
+}
+
+bool Library::isEpub(const QString &url)
+{
+
+    return url.endsWith(".epub", Qt::CaseSensitivity::CaseInsensitive);
+}
+
+bool Library::isCommicBook(const QString &url)
+{
+    auto mime = FMStatic::getMime(url);
+    return mime == "application/vnd.comicbook+zip" || mime == "application/vnd.comicbook+rar";
 }
 
 
