@@ -1,5 +1,4 @@
-#ifndef LIBRARY_H
-#define LIBRARY_H
+#pragma once
 
 #include <QObject>
 
@@ -14,19 +13,23 @@ public:
     QVariantList sourcesModel() const;
     QStringList sources() const;
 
-public slots:
+public Q_SLOTS:
     void openFiles(QStringList files);
     void removeSource(const QString &url);
     void addSources(const QStringList &urls);
 
+    bool isPDF(const QString &url);
+    bool isPlainText(const QString &url);
+    bool isEpub(const QString &url);
+    bool isCommicBook(const QString &url);
+
 private:
     static Library *m_instance;
     explicit Library(QObject *parent = nullptr);
     QStringList m_sources;
-signals:
+
+Q_SIGNALS:
     void requestedFiles(QList<QUrl> files);
     void sourcesChanged(QStringList sources);
 
 };
-
-#endif // LIBRARY_H
