@@ -17,13 +17,13 @@ bool registerService();
 class Server : public QObject
 {
     Q_OBJECT
-    Q_CLASSINFO("D-Bus Interface", "org.maui.settings.Actions")
+    Q_CLASSINFO("D-Bus Interface", "org.maui.shelf.Actions")
 
 public:
     explicit Server(QObject *parent = nullptr);
     void setQmlObject(QObject  *object);
 
-public slots:
+public Q_SLOTS:
     /**
            * Tries to raise/activate the Dolphin window.
            */
@@ -47,7 +47,5 @@ private:
     QObject* m_qmlObject = nullptr;
     QStringList filterFiles(const QStringList &urls);
 
-signals:
-
 };
 
